'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var constants = require('../common/constants.js');
var httpClient = require('./http-client.js');

const isObject = data => typeof data === 'object' && data !== null;
const isNotLoggedInError = data => isObject(data) && data['name'] === 'NotLoggedInError';
class RestApi {
  token;
  httpClient;

  constructor(token, httpClient$1 = new httpClient.DefaultHttpClient()) {
    this.token = token;
    this.httpClient = httpClient$1;
  }

  async getPage(projectName, pageName) {
    return this.request(`${constants.constants.rest.baseUrl}/pages/${encodeURIComponent(projectName)}/${encodeURIComponent(pageName)}?followRename=true`);
  }

  async getProject(projectName) {
    return this.request(`${constants.constants.rest.baseUrl}/projects/${encodeURIComponent(projectName)}`);
  }

  async getProjects() {
    return this.request(`${constants.constants.rest.baseUrl}/projects`);
  }

  async getMe() {
    return this.request(`${constants.constants.rest.baseUrl}/users/me`);
  }

  async request(url) {
    const result = await this.httpClient.get(url, {
      headers: {
        Cookie: `connect.sid=${this.token}`
      }
    });

    if (isNotLoggedInError(result)) {
      throw new Error('NotLoggedInError');
    }

    return result;
  }

}

exports.RestApi = RestApi;
exports.isNotLoggedInError = isNotLoggedInError;
exports.isObject = isObject;
//# sourceMappingURL=rest-api.js.map
