'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');
var scrapbox = require('../user-script/scrapbox.js');

const concatPageLines = lines => {
  const [, ...contentsLines] = lines; // drop first title line

  return contentsLines.map(({
    text
  }) => text).join('');
};

class DynamicConfig {
  api;
  data$ = new rxjs.ReplaySubject(1);

  get data() {
    return rxjs.firstValueFrom(this.data$);
  }

  constructor(api) {
    this.api = api;
    this.#loadConfig().catch(console.error);
  }

  async #loadConfig() {
    let config = {};

    try {
      const page = await this.api.getPage(scrapbox.UserScriptApi.projectName, 'config');
      const json = concatPageLines(page.lines);
      config = JSON.parse(json);
    } catch (e) {
      console.error(e);
    }

    this.data$.next({ ...config
    });
  }

}

exports.DynamicConfig = DynamicConfig;
//# sourceMappingURL=dynamic-config.js.map
