'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');
var operators = require('rxjs/operators');

const findElementOrFail = (selector, parent = document) => {
  const elem = parent.querySelector(selector);

  if (!elem) {
    throw new Error('Element not found');
  }

  return elem;
};
const nodeChange = (node, options) => {
  return new rxjs.Observable(subscriber => {
    const mo = new MutationObserver(() => subscriber.next());
    mo.observe(node, options);
    return () => mo.disconnect();
  }).pipe(operators.share());
}; // NOTE: scrapbox.Project.name is set after react bootstrapped

const isScrapboxReady = () => Boolean(window.scrapbox.Project && window.scrapbox.Project.name);
const scrapboxReady = () => {
  return new rxjs.Observable(subscriber => {
    const subscription = rxjs.timer(0, 30).subscribe(() => {
      if (isScrapboxReady()) {
        subscriber.next(window.scrapbox);
        subscriber.complete();
        subscription.unsubscribe();
      }
    });
    return subscription;
  });
};

exports.findElementOrFail = findElementOrFail;
exports.isScrapboxReady = isScrapboxReady;
exports.nodeChange = nodeChange;
exports.scrapboxReady = scrapboxReady;
//# sourceMappingURL=util.js.map
